@@ -127,23 +127,36 @@ class SockJSProxy(object):
     def collect_args(self):
         parser = argparse.ArgumentParser(description="Proxy messages between sock.js and a 0MQ socket")
         parser.add_argument('--address', '-a', type=str,
-                            help="The address to listen. Defaults to * (meaning - everything)",
+                            help="The 0MQ address to listen to. Defaults to * (meaning - everything)",
                             default='*')
+
         parser.add_argument('--in-port', '-i', type=int,
-                            help="The port to listen for incoming connections. Defaults to 9241",
+                            help="The port to listen for incoming 0MQ connections. Defaults to 9241",
                             default=9241)
         parser.add_argument('--out-port', '-o', type=int,
-                            help="The port to listen for outgoing connections. Defaults to 9242",
+                            help="The port to listen for outgoing 0MQ connections. Defaults to 9242",
                             default=9242)
+
         parser.add_argument('--http-port', '-p', type=int,
                             help="The port to listen for http (sock.js) connections. Defaults to 8080",
                             default=8080)
+
+        parser.add_argument('--static-path', '-s', type=str,
+                            help="The path to a local static directory to be server under --static-url")
+        parser.add_argument('--static-url', '-u', type=str,
+                            help="The url where the files in --static-path will be served")
+
         parser.add_argument('--samples', type=str,
-                            help='Serve samples under SAMPLES', default='samples')
+                            help='Serve samples under /path/you/specify')
         parser.add_argument('--verbose', action='store_true', default=False,
                             help='Make the server output more information - useful for debugging')
 
-        return parser.parse_args()
+        args = parser.parse_args()
+
+        if bool(args.static_path) != bool(args.static_url):
+            parser.error("You should specify both --static-path and --static-url to have static files served.")
+
+        return args
 
     def init_logging(self, verbose):
         log.setLevel(logging.DEBUG if verbose else logging.INFO)
@@ -176,16 +189,24 @@ class SockJSProxy(object):
 
         sockjs_router = SockJSRouter(FrontendTransport, io_loop=io_loop)
 
+        routes = sockjs_router.urls
+
         if args.samples:
-            static_path = '/' + args.samples.strip('/')
-            log.info("Serving samples content at %s", static_path)
-            routes = (sockjs_router.urls +
-                      [(r"%s/(.*)" % static_path, web.StaticFileHandler,
+            sample_url = '/' + args.samples.strip('/')
+            log.info("Serving samples content at %s", sample_url)
+            routes += [(r"%s/?(.*)" % sample_url, web.StaticFileHandler,
                         {"path": './sockjsproxy/samples', "default_filename": "index.html"}),
-                       (r"%s()" % static_path, web.StaticFileHandler,
-                        {"path": './sockjsproxy/samples', "default_filename": "index.html"})])
-        else:
-            routes = sockjs_router.urls
+                       (r"%s()" % sample_url, web.StaticFileHandler,
+                        {"path": './sockjsproxy/samples', "default_filename": "index.html"})]
+
+        if args.static_path and args.static_url:
+            static_url = '/' + args.static_url.strip('/')
+            log.info("Serving static directory %s at %s", args.static_path, static_url)
+            routes += [(r"%s/?(.*)" % static_url, web.StaticFileHandler,
+                        {"path": args.static_path, "default_filename": "index.html"}),
+                       (r"%s()" % static_url, web.StaticFileHandler,
+                        {"path": args.static_path, "default_filename": "index.html"})]
+
         web_app = web.Application(routes, debug=False)
 
         web_server = HTTPServer(web_app)
